==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControl/src/com/clustercontrol/monitor/run/bean/MonitorTruthValueInfo.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.monitor.run.bean;


/**
 * ʹƻȽ󥯥饹Ǥ
 * 
 * @version 2.1.0
 * @since 2.0.0
 */
public class MonitorTruthValueInfo
	extends MonitorJudgementInfo
{
	private static final long serialVersionUID = -8164764456414755011L;
	
	/**  */
	protected int m_truthValue;
	
	
	/**
	 * 󥹥ȥ饯
	 */
	public MonitorTruthValueInfo() {
		super();
	}
	
	/**
	 * 󥹥ȥ饯
	 * 
	 * @param message
	 * @param messageId
	 * @param monitorId
	 * @param monitorTypeId
	 * @param priority
	 * @param truthValue
	 * @param jobRun
	 * @param jobId
	 * @param jobInhibitionFlg
	 * @param jobFailurePriority
	 */
	public MonitorTruthValueInfo( 
			String message,
			String messageId,
			String monitorId,
			String monitorTypeId,
			int priority,
			int truthValue,
			int jobRun,
			String jobId,
			int jobInhibitionFlg,
			int jobFailurePriority )
	{
		setMessage(message);
		setMessageId(messageId);
		setMonitorId(monitorId);
		setMonitorTypeId(monitorTypeId);
		setPriority(priority);
		setTruthValue(truthValue);
		setJobRun(jobRun);
		setJobId(jobId);
		setJobInhibitionFlg(jobInhibitionFlg);
		setJobFailurePriority(jobFailurePriority);
	}
	
	
	/**
	 * 󥹥ȥ饯
	 * 
	 * @param otherData
	 */
	public MonitorTruthValueInfo( MonitorTruthValueInfo otherData )
	{
		setMessage(otherData.getMessage());
		setMessageId(otherData.getMessageId());
		setMonitorId(otherData.getMonitorId());
		setMonitorTypeId(otherData.getMonitorTypeId());
		setPriority(otherData.getPriority());
		setTruthValue(otherData.getTruthValue());
		setJobRun(otherData.getJobRun());
		setJobId(otherData.getJobId());
		setJobInhibitionFlg(otherData.getJobInhibitionFlg());
		setJobFailurePriority(otherData.getJobFailurePriority());
	}
	
	/**
	 * @return m_truthValue ᤷޤ
	 */
	public int getTruthValue() {
		return m_truthValue;
	}
	
	/**
	 * @param truthValue ꤹ m_truthValue
	 */
	public void setTruthValue(int truthValue) {
		this.m_truthValue = truthValue;
	}
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControl/src/com/clustercontrol/monitor/run/bean/MonitorTruthValueInfo.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.monitor.run.bean;


/**
 * 真偽値監視判定情報クラスです。
 * 
 * @version 2.1.0
 * @since 2.0.0
 */
public class MonitorTruthValueInfo
	extends MonitorJudgementInfo
{
	private static final long serialVersionUID = -8164764456414755011L;
	
	/** 真偽値 */
	protected int m_truthValue;
	
	
	/**
	 * コンストラクタ
	 */
	public MonitorTruthValueInfo() {
		super();
	}
	
	/**
	 * コンストラクタ
	 * 
	 * @param message
	 * @param messageId
	 * @param monitorId
	 * @param monitorTypeId
	 * @param priority
	 * @param truthValue
	 * @param jobRun
	 * @param jobId
	 * @param jobInhibitionFlg
	 * @param jobFailurePriority
	 */
	public MonitorTruthValueInfo( 
			String message,
			String messageId,
			String monitorId,
			String monitorTypeId,
			int priority,
			int truthValue,
			int jobRun,
			String jobId,
			int jobInhibitionFlg,
			int jobFailurePriority )
	{
		setMessage(message);
		setMessageId(messageId);
		setMonitorId(monitorId);
		setMonitorTypeId(monitorTypeId);
		setPriority(priority);
		setTruthValue(truthValue);
		setJobRun(jobRun);
		setJobId(jobId);
		setJobInhibitionFlg(jobInhibitionFlg);
		setJobFailurePriority(jobFailurePriority);
	}
	
	
	/**
	 * コンストラクタ
	 * 
	 * @param otherData
	 */
	public MonitorTruthValueInfo( MonitorTruthValueInfo otherData )
	{
		setMessage(otherData.getMessage());
		setMessageId(otherData.getMessageId());
		setMonitorId(otherData.getMonitorId());
		setMonitorTypeId(otherData.getMonitorTypeId());
		setPriority(otherData.getPriority());
		setTruthValue(otherData.getTruthValue());
		setJobRun(otherData.getJobRun());
		setJobId(otherData.getJobId());
		setJobInhibitionFlg(otherData.getJobInhibitionFlg());
		setJobFailurePriority(otherData.getJobFailurePriority());
	}
	
	/**
	 * @return m_truthValue を戻します。
	 */
	public int getTruthValue() {
		return m_truthValue;
	}
	
	/**
	 * @param truthValue 設定する m_truthValue。
	 */
	public void setTruthValue(int truthValue) {
		this.m_truthValue = truthValue;
	}
}
